Enum quinn_proto::ReadError
source · pub enum ReadError {
Blocked,
Reset(VarInt),
}Expand description
Errors triggered when reading from a recv stream
Variants
Blocked
No more data is currently available on this stream.
If more data on this stream is received from the peer, an Event::StreamReadable will be
generated for this stream, indicating that retrying the read might succeed.
Reset(VarInt)
The peer abandoned transmitting data on this stream.
Carries an application-defined error code.